### Name: mcmcFmodel
### Title: Inference in a spatial statistical model
### Aliases: mcmcFmodel


### ** Examples

  # Below is a complete sequence 
  # of commands using Geneland functions

  # we assume that Geneland is installed
  # and loaded by library("Geneland")

 # Simulation of a dataset made of 2 populations
 # 5 loci and 10 alleles per locus
 # on a spatial domain enclosed in a rectangle
 # (x coord. in [0,3], y coord. in [0,1])
 # domain of populations are centered around 
 # points (0.5,0.5) and (2.5,0.5) respectively 
 # (so that the boundary is the vertical line x = 1.5)
sim = simFmodel(nindiv=100,
          coord.lim=c(0,3,0,1),
          number.nuclei=2,
          coord.nuclei=cbind(c(0.5,0.5),c(2.5,0.5)),
          color.nuclei=c(1,2),
          nloc=5,
          nall=rep(10,5),
          npop=2,
          drift=c(.3,.3),
          plots=FALSE,
          ploth=FALSE,
          seed=123)

  # you can check the simulated dataset by
ls()  ## gives a list of existing objects

summary(sim) ## describes roughly what object sim actually contains

  #  define a place for MCMC outputs
path.mcmc = paste(tempdir(),"/",sep="")

  # First run of MCMC algorithm
  # in order to get the posterior mode of the number of populations
mcmcFmodel(sim$coordinates,sim$genotypes,sim$allele.numbers,
           path.mcmc=path.mcmc,
           rate.max=100,
           delta.coord=0,
           npopmin=1,
           npopinit=5,
           npopmax=10,
           nb.nuclei.max=200,
           nit=50000,
           thinning=50,
           freq.model="Dirichlet",
           varnpop=TRUE,
           spatial=TRUE)

  # Trace of number of populations
  # Should display a mode at 2
Plotnpop(path.mcmc)

 # Then re-run the chain with fixed number of populations
mcmcFmodel(sim$coordinates,sim$genotypes,sim$allele.numbers,
           path.mcmc=path.mcmc,
           rate.max=100,
           delta.coord=0,
           npopmin=1,
           npopinit=2,
           npopmax=2,
           nb.nuclei.max=200,
           nit=5000,
           thinning=10,
           freq.model="Dirichlet",
           varnpop=FALSE,
           spatial=TRUE)

   # Post-processing the chain 
PostProcessChain(sim$coordinates,sim$genotypes,sim$allele.numbers,
                  path.mcmc=path.mcmc,
                  nxdom=50,
                  nydom=50,
                  burnin=0)

   # Plots allele frequencies of allele #1 at locus  #1 in sub-population  #1
 PlotFreq(sim$allele.numbers,
path.mcmc=path.mcmc,ipop=1,iloc=1,iall=1)

   # Map of posterior probabilites
   # of population membership
 PlotTessellation(sim$coordinates,path.mcmc=path.mcmc)

   # Map of posterior mode 
   # of population membership
 PosteriorMode(sim$coordinates,path.mcmc=path.mcmc,
               write=FALSE,plotit=TRUE)

 # read the estimated population for indivuals
 pppm.indiv <- scan(paste(path.mcmc,"modal.pop.indiv.txt",sep=""))

 # add a plot of the individual colored as their estimated population of origin
points(sim$coordinates,col=pppm.indiv,pch=16)





